camelot.camelot.view.controls.editors

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors |
[hide private]
[frames] | no frames]

# Module editors

source code

Editors for various type of values

Classes | [hide private]
| DateEditor Widget for editing date values
| VirtualAddressEditor
| CodeEditor
| EmbeddedMany2OneEditor Widget for editing a many 2 one relation a a form embedded in another form.
| Many2OneEditor Widget for editing many 2 one relations
| One2ManyEditor
| ImageEditor
| RichTextEditor

Functions | [hide private]
create_constant_function(constant) | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.editors')`
| filter = `"""Image files (*.bmp *.jpg *.jpeg *.mng *.png *.pbm `...``

Variables Details | [hide private]

  ### filter Value:
      """Image files (*.bmp *.jpg *.jpeg *.mng *.png *.pbm *.pgm """ """*.pp
      m *.tiff *.xbm *.xpm)
      All files (*)"""